# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/agent/agent_interaction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/agent/agent_interaction.proto\x12\x0eprodvana.agent\x1a\x1bgoogle/api/visibility.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\"\n\x0cHeartbeatReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x0f\n\rHeartbeatResp\"\x95\x01\n\x17RecordNewUnknownPushReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1a\n\x18RecordNewUnknownPushResp\"\xc5\x01\n\x12RecordPushStartReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x33\n\x0fstart_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x15\n\x13RecordPushStartResp\"\x92\x01\n\x14RecordPushOngoingReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"\x17\n\x15RecordPushOngoingResp\"\x82\x02\n\x15RecordPushCompleteReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.prodvana.agent.RecordPushCompleteReq.Type\"3\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x0f\n\x0bROLLED_BACK\x10\x02\"\x18\n\x16RecordPushCompleteResp\"\x94\x01\n\x16\x43onfirmPushApprovalReq\x12\x1a\n\x12release_channel_id\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncluster_id\x18\x03 \x01(\t\"+\n\x17\x43onfirmPushApprovalResp\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\"_\n\x0cRecordPodReq\x12\x0b\n\x03pod\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\x12\x12\n\nruntime_id\x18\x03 \x01(\t\"\x0f\n\rRecordPodResp\"1\n\rRecordPodsReq\x12\x0c\n\x04pods\x18\x01 \x03(\x0c\x12\x12\n\nruntime_id\x18\x02 \x01(\t\"\x10\n\x0eRecordPodsResp\"Y\n\x13RecordDeploymentReq\x12\x12\n\ndeployment\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"J\n\x14RecordDeploymentResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x10RecordRolloutReq\x12\x0f\n\x07rollout\x18\x01 \x01(\x0c\x12.\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1e.prodvana.agent.InformerAction\"G\n\x11RecordRolloutResp\x12\x32\n\x0epush_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"@\n\x11ProxyAPIServerReq\x12\x14\n\nruntime_id\x18\x01 \x01(\tH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\x42\x05\n\x03msg\"\x8e\x01\n\x12ProxyAPIServerResp\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32\'.prodvana.agent.ProxyAPIServerResp.TypeH\x00\x12\x0e\n\x04\x62lob\x18\x02 \x01(\x0cH\x00\"(\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fPROXY_APISERVER\x10\x01\x42\x05\n\x03msg\"5\n\tDebugInfo\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x19\n\x11tcptraceroute_out\x18\x02 \x01(\t\"Q\n\x12ReportDebugInfoReq\x12\x12\n\nruntime_id\x18\x01 \x01(\t\x12\'\n\x04info\x18\x02 \x01(\x0b\x32\x19.prodvana.agent.DebugInfo\"\x15\n\x13ReportDebugInfoResp*1\n\x0eInformerAction\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x32\x81\t\n\x10\x41gentInteraction\x12J\n\tHeartbeat\x12\x1c.prodvana.agent.HeartbeatReq\x1a\x1d.prodvana.agent.HeartbeatResp\"\x00\x12h\n\x13\x43onfirmPushApproval\x12&.prodvana.agent.ConfirmPushApprovalReq\x1a\'.prodvana.agent.ConfirmPushApprovalResp\"\x00\x12k\n\x14RecordNewUnknownPush\x12\'.prodvana.agent.RecordNewUnknownPushReq\x1a(.prodvana.agent.RecordNewUnknownPushResp\"\x00\x12\\\n\x0fRecordPushStart\x12\".prodvana.agent.RecordPushStartReq\x1a#.prodvana.agent.RecordPushStartResp\"\x00\x12\x62\n\x11RecordPushOngoing\x12$.prodvana.agent.RecordPushOngoingReq\x1a%.prodvana.agent.RecordPushOngoingResp\"\x00\x12\x65\n\x12RecordPushComplete\x12%.prodvana.agent.RecordPushCompleteReq\x1a&.prodvana.agent.RecordPushCompleteResp\"\x00\x12J\n\tRecordPod\x12\x1c.prodvana.agent.RecordPodReq\x1a\x1d.prodvana.agent.RecordPodResp\"\x00\x12M\n\nRecordPods\x12\x1d.prodvana.agent.RecordPodsReq\x1a\x1e.prodvana.agent.RecordPodsResp\"\x00\x12_\n\x10RecordDeployment\x12#.prodvana.agent.RecordDeploymentReq\x1a$.prodvana.agent.RecordDeploymentResp\"\x00\x12V\n\rRecordRollout\x12 .prodvana.agent.RecordRolloutReq\x1a!.prodvana.agent.RecordRolloutResp\"\x00\x12]\n\x0eProxyAPIServer\x12!.prodvana.agent.ProxyAPIServerReq\x1a\".prodvana.agent.ProxyAPIServerResp\"\x00(\x01\x30\x01\x12\\\n\x0fReportDebugInfo\x12\".prodvana.agent.ReportDebugInfoReq\x1a#.prodvana.agent.ReportDebugInfoResp\"\x00\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALBJZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agentb\x06proto3')

_INFORMERACTION = DESCRIPTOR.enum_types_by_name['InformerAction']
InformerAction = enum_type_wrapper.EnumTypeWrapper(_INFORMERACTION)
ADD = 0
UPDATE = 1
DELETE = 2


_HEARTBEATREQ = DESCRIPTOR.message_types_by_name['HeartbeatReq']
_HEARTBEATRESP = DESCRIPTOR.message_types_by_name['HeartbeatResp']
_RECORDNEWUNKNOWNPUSHREQ = DESCRIPTOR.message_types_by_name['RecordNewUnknownPushReq']
_RECORDNEWUNKNOWNPUSHRESP = DESCRIPTOR.message_types_by_name['RecordNewUnknownPushResp']
_RECORDPUSHSTARTREQ = DESCRIPTOR.message_types_by_name['RecordPushStartReq']
_RECORDPUSHSTARTRESP = DESCRIPTOR.message_types_by_name['RecordPushStartResp']
_RECORDPUSHONGOINGREQ = DESCRIPTOR.message_types_by_name['RecordPushOngoingReq']
_RECORDPUSHONGOINGRESP = DESCRIPTOR.message_types_by_name['RecordPushOngoingResp']
_RECORDPUSHCOMPLETEREQ = DESCRIPTOR.message_types_by_name['RecordPushCompleteReq']
_RECORDPUSHCOMPLETERESP = DESCRIPTOR.message_types_by_name['RecordPushCompleteResp']
_CONFIRMPUSHAPPROVALREQ = DESCRIPTOR.message_types_by_name['ConfirmPushApprovalReq']
_CONFIRMPUSHAPPROVALRESP = DESCRIPTOR.message_types_by_name['ConfirmPushApprovalResp']
_RECORDPODREQ = DESCRIPTOR.message_types_by_name['RecordPodReq']
_RECORDPODRESP = DESCRIPTOR.message_types_by_name['RecordPodResp']
_RECORDPODSREQ = DESCRIPTOR.message_types_by_name['RecordPodsReq']
_RECORDPODSRESP = DESCRIPTOR.message_types_by_name['RecordPodsResp']
_RECORDDEPLOYMENTREQ = DESCRIPTOR.message_types_by_name['RecordDeploymentReq']
_RECORDDEPLOYMENTRESP = DESCRIPTOR.message_types_by_name['RecordDeploymentResp']
_RECORDROLLOUTREQ = DESCRIPTOR.message_types_by_name['RecordRolloutReq']
_RECORDROLLOUTRESP = DESCRIPTOR.message_types_by_name['RecordRolloutResp']
_PROXYAPISERVERREQ = DESCRIPTOR.message_types_by_name['ProxyAPIServerReq']
_PROXYAPISERVERRESP = DESCRIPTOR.message_types_by_name['ProxyAPIServerResp']
_DEBUGINFO = DESCRIPTOR.message_types_by_name['DebugInfo']
_REPORTDEBUGINFOREQ = DESCRIPTOR.message_types_by_name['ReportDebugInfoReq']
_REPORTDEBUGINFORESP = DESCRIPTOR.message_types_by_name['ReportDebugInfoResp']
_RECORDPUSHCOMPLETEREQ_TYPE = _RECORDPUSHCOMPLETEREQ.enum_types_by_name['Type']
_PROXYAPISERVERRESP_TYPE = _PROXYAPISERVERRESP.enum_types_by_name['Type']
HeartbeatReq = _reflection.GeneratedProtocolMessageType('HeartbeatReq', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.HeartbeatReq)
  })
_sym_db.RegisterMessage(HeartbeatReq)

HeartbeatResp = _reflection.GeneratedProtocolMessageType('HeartbeatResp', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.HeartbeatResp)
  })
_sym_db.RegisterMessage(HeartbeatResp)

RecordNewUnknownPushReq = _reflection.GeneratedProtocolMessageType('RecordNewUnknownPushReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDNEWUNKNOWNPUSHREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordNewUnknownPushReq)
  })
_sym_db.RegisterMessage(RecordNewUnknownPushReq)

RecordNewUnknownPushResp = _reflection.GeneratedProtocolMessageType('RecordNewUnknownPushResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDNEWUNKNOWNPUSHRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordNewUnknownPushResp)
  })
_sym_db.RegisterMessage(RecordNewUnknownPushResp)

RecordPushStartReq = _reflection.GeneratedProtocolMessageType('RecordPushStartReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHSTARTREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushStartReq)
  })
_sym_db.RegisterMessage(RecordPushStartReq)

RecordPushStartResp = _reflection.GeneratedProtocolMessageType('RecordPushStartResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHSTARTRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushStartResp)
  })
_sym_db.RegisterMessage(RecordPushStartResp)

RecordPushOngoingReq = _reflection.GeneratedProtocolMessageType('RecordPushOngoingReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHONGOINGREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushOngoingReq)
  })
_sym_db.RegisterMessage(RecordPushOngoingReq)

RecordPushOngoingResp = _reflection.GeneratedProtocolMessageType('RecordPushOngoingResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHONGOINGRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushOngoingResp)
  })
_sym_db.RegisterMessage(RecordPushOngoingResp)

RecordPushCompleteReq = _reflection.GeneratedProtocolMessageType('RecordPushCompleteReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHCOMPLETEREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushCompleteReq)
  })
_sym_db.RegisterMessage(RecordPushCompleteReq)

RecordPushCompleteResp = _reflection.GeneratedProtocolMessageType('RecordPushCompleteResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPUSHCOMPLETERESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPushCompleteResp)
  })
_sym_db.RegisterMessage(RecordPushCompleteResp)

ConfirmPushApprovalReq = _reflection.GeneratedProtocolMessageType('ConfirmPushApprovalReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMPUSHAPPROVALREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ConfirmPushApprovalReq)
  })
_sym_db.RegisterMessage(ConfirmPushApprovalReq)

ConfirmPushApprovalResp = _reflection.GeneratedProtocolMessageType('ConfirmPushApprovalResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMPUSHAPPROVALRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ConfirmPushApprovalResp)
  })
_sym_db.RegisterMessage(ConfirmPushApprovalResp)

RecordPodReq = _reflection.GeneratedProtocolMessageType('RecordPodReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPODREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPodReq)
  })
_sym_db.RegisterMessage(RecordPodReq)

RecordPodResp = _reflection.GeneratedProtocolMessageType('RecordPodResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPODRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPodResp)
  })
_sym_db.RegisterMessage(RecordPodResp)

RecordPodsReq = _reflection.GeneratedProtocolMessageType('RecordPodsReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPODSREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPodsReq)
  })
_sym_db.RegisterMessage(RecordPodsReq)

RecordPodsResp = _reflection.GeneratedProtocolMessageType('RecordPodsResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDPODSRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordPodsResp)
  })
_sym_db.RegisterMessage(RecordPodsResp)

RecordDeploymentReq = _reflection.GeneratedProtocolMessageType('RecordDeploymentReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDDEPLOYMENTREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordDeploymentReq)
  })
_sym_db.RegisterMessage(RecordDeploymentReq)

RecordDeploymentResp = _reflection.GeneratedProtocolMessageType('RecordDeploymentResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDDEPLOYMENTRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordDeploymentResp)
  })
_sym_db.RegisterMessage(RecordDeploymentResp)

RecordRolloutReq = _reflection.GeneratedProtocolMessageType('RecordRolloutReq', (_message.Message,), {
  'DESCRIPTOR' : _RECORDROLLOUTREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordRolloutReq)
  })
_sym_db.RegisterMessage(RecordRolloutReq)

RecordRolloutResp = _reflection.GeneratedProtocolMessageType('RecordRolloutResp', (_message.Message,), {
  'DESCRIPTOR' : _RECORDROLLOUTRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.RecordRolloutResp)
  })
_sym_db.RegisterMessage(RecordRolloutResp)

ProxyAPIServerReq = _reflection.GeneratedProtocolMessageType('ProxyAPIServerReq', (_message.Message,), {
  'DESCRIPTOR' : _PROXYAPISERVERREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ProxyAPIServerReq)
  })
_sym_db.RegisterMessage(ProxyAPIServerReq)

ProxyAPIServerResp = _reflection.GeneratedProtocolMessageType('ProxyAPIServerResp', (_message.Message,), {
  'DESCRIPTOR' : _PROXYAPISERVERRESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ProxyAPIServerResp)
  })
_sym_db.RegisterMessage(ProxyAPIServerResp)

DebugInfo = _reflection.GeneratedProtocolMessageType('DebugInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGINFO,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.DebugInfo)
  })
_sym_db.RegisterMessage(DebugInfo)

ReportDebugInfoReq = _reflection.GeneratedProtocolMessageType('ReportDebugInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDEBUGINFOREQ,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ReportDebugInfoReq)
  })
_sym_db.RegisterMessage(ReportDebugInfoReq)

ReportDebugInfoResp = _reflection.GeneratedProtocolMessageType('ReportDebugInfoResp', (_message.Message,), {
  'DESCRIPTOR' : _REPORTDEBUGINFORESP,
  '__module__' : 'prodvana.agent.agent_interaction_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.agent.ReportDebugInfoResp)
  })
_sym_db.RegisterMessage(ReportDebugInfoResp)

_AGENTINTERACTION = DESCRIPTOR.services_by_name['AgentInteraction']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/agent'
  _AGENTINTERACTION._options = None
  _AGENTINTERACTION._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _INFORMERACTION._serialized_start=2113
  _INFORMERACTION._serialized_end=2162
  _HEARTBEATREQ._serialized_start=120
  _HEARTBEATREQ._serialized_end=154
  _HEARTBEATRESP._serialized_start=156
  _HEARTBEATRESP._serialized_end=171
  _RECORDNEWUNKNOWNPUSHREQ._serialized_start=174
  _RECORDNEWUNKNOWNPUSHREQ._serialized_end=323
  _RECORDNEWUNKNOWNPUSHRESP._serialized_start=325
  _RECORDNEWUNKNOWNPUSHRESP._serialized_end=351
  _RECORDPUSHSTARTREQ._serialized_start=354
  _RECORDPUSHSTARTREQ._serialized_end=551
  _RECORDPUSHSTARTRESP._serialized_start=553
  _RECORDPUSHSTARTRESP._serialized_end=574
  _RECORDPUSHONGOINGREQ._serialized_start=577
  _RECORDPUSHONGOINGREQ._serialized_end=723
  _RECORDPUSHONGOINGRESP._serialized_start=725
  _RECORDPUSHONGOINGRESP._serialized_end=748
  _RECORDPUSHCOMPLETEREQ._serialized_start=751
  _RECORDPUSHCOMPLETEREQ._serialized_end=1009
  _RECORDPUSHCOMPLETEREQ_TYPE._serialized_start=958
  _RECORDPUSHCOMPLETEREQ_TYPE._serialized_end=1009
  _RECORDPUSHCOMPLETERESP._serialized_start=1011
  _RECORDPUSHCOMPLETERESP._serialized_end=1035
  _CONFIRMPUSHAPPROVALREQ._serialized_start=1038
  _CONFIRMPUSHAPPROVALREQ._serialized_end=1186
  _CONFIRMPUSHAPPROVALRESP._serialized_start=1188
  _CONFIRMPUSHAPPROVALRESP._serialized_end=1231
  _RECORDPODREQ._serialized_start=1233
  _RECORDPODREQ._serialized_end=1328
  _RECORDPODRESP._serialized_start=1330
  _RECORDPODRESP._serialized_end=1345
  _RECORDPODSREQ._serialized_start=1347
  _RECORDPODSREQ._serialized_end=1396
  _RECORDPODSRESP._serialized_start=1398
  _RECORDPODSRESP._serialized_end=1414
  _RECORDDEPLOYMENTREQ._serialized_start=1416
  _RECORDDEPLOYMENTREQ._serialized_end=1505
  _RECORDDEPLOYMENTRESP._serialized_start=1507
  _RECORDDEPLOYMENTRESP._serialized_end=1581
  _RECORDROLLOUTREQ._serialized_start=1583
  _RECORDROLLOUTREQ._serialized_end=1666
  _RECORDROLLOUTRESP._serialized_start=1668
  _RECORDROLLOUTRESP._serialized_end=1739
  _PROXYAPISERVERREQ._serialized_start=1741
  _PROXYAPISERVERREQ._serialized_end=1805
  _PROXYAPISERVERRESP._serialized_start=1808
  _PROXYAPISERVERRESP._serialized_end=1950
  _PROXYAPISERVERRESP_TYPE._serialized_start=1903
  _PROXYAPISERVERRESP_TYPE._serialized_end=1943
  _DEBUGINFO._serialized_start=1952
  _DEBUGINFO._serialized_end=2005
  _REPORTDEBUGINFOREQ._serialized_start=2007
  _REPORTDEBUGINFOREQ._serialized_end=2088
  _REPORTDEBUGINFORESP._serialized_start=2090
  _REPORTDEBUGINFORESP._serialized_end=2111
  _AGENTINTERACTION._serialized_start=2165
  _AGENTINTERACTION._serialized_end=3318
# @@protoc_insertion_point(module_scope)
